Struct oauth2::authz_server::AuthzRequestData
[−]
[src]
pub struct AuthzRequestData {
pub id: Option<String>,
pub client_id: String,
pub redirect_uri: Option<String>,
pub scope: Option<String>,
pub state: Option<String>,
pub authorization_code: Option<String>,
pub error: Option<AuthzError>,
}Fields
id: Option<String>
Some token to distinguish this request
client_id: String
client_id as supplied in the request
redirect_uri: Option<String>
redirect_uri as supplied in the request, or None if not supplied
scope: Option<String>
scope as supplied in the request
state: Option<String>
state as supplied in the request. We recommend implementations should error if a state was not supplied in the request.
The authorization code, IF the request has been approved.
error: Option<AuthzError>
An error, if an error has occurred