Enum oauth2::client_type::ClientType
[−]
[src]
pub enum ClientType {
ConfidentialClient,
PublicClient,
}Client Type, either 'confidential' or 'public'.
See RFC 6749 Section 2.2. In particular:
- If the client cannot be trusted with secrets, it is 'public'. This usually includes all clients in end-user hands like javascript ones, but strictly speaking it depends on your security model.
Variants
ConfidentialClientClient that can confidentially store secrets
PublicClientClient that is not trusted to confidentially store secrets